==> pegasus-merchandise-api-1.5.3-sources.jar: com/thebeastshop/pegasus/merchandise/vo/PcsSkuDTO.java <==
package com.thebeastshop.pegasus.merchandise.vo;

import java.io.Serializable;

/**
 * Created by Administrator on 2017/9/11.
 */
public class PcsSkuDTO implements Serializable {

  private String nameCn;

  private Integer skuType;

  private Long categoryId;

  private Integer crossBorderFlag;

  private Integer isJit;

  private Integer isOwnImported;

  private Integer skuStatus;

  /**
   * SKU类型
   * @return
   */
  public String getSkuTypeStr() {
    String result = "";
    if (this.skuType != null) {
      // 1原材料2半成品3成品
      if (this.skuType.intValue() == 1) {
        result = "原材料";
      } else if (this.skuType.intValue() == 2) {
        result = "半成品";
      } else if (this.skuType.intValue() == 3) {
        result = "成品";
      }
    }
    return result;
  }

  public String getNameCn() {
    return nameCn;
  }

  public void setNameCn(String nameCn) {
    this.nameCn = nameCn;
  }

  public Integer getSkuType() {
    return skuType;
  }

  public void setSkuType(Integer skuType) {
    this.skuType = skuType;
  }



  public Integer getCrossBorderFlag() {
    return crossBorderFlag;
  }

  public void setCrossBorderFlag(Integer crossBorderFlag) {
    this.crossBorderFlag = crossBorderFlag;
  }

  public Integer getIsJit() {
    return isJit;
  }

  public void setIsJit(Integer isJit) {
    this.isJit = isJit;
  }

  public Long getCategoryId() {
    return categoryId;
  }

  public void setCategoryId(Long categoryId) {
    this.categoryId = categoryId;
  }

  public Integer getIsOwnImported() {
    return isOwnImported;
  }

  public void setIsOwnImported(Integer isOwnImported) {
    this.isOwnImported = isOwnImported;
  }

  public Integer getSkuStatus() {
    return skuStatus;
  }

  public void setSkuStatus(Integer skuStatus) {
    this.skuStatus = skuStatus;
  }
}

==> pegasus-merchandise-api-1.6.5-sources.jar: com/thebeastshop/pegasus/merchandise/vo/PcsSkuDTO.java <==
package com.thebeastshop.pegasus.merchandise.vo;

import java.io.Serializable;

/**
 * Created by Administrator on 2017/9/11.
 */
public class PcsSkuDTO implements Serializable {


  private String skuCode;

  private String nameCn;

  private Integer skuType;

  private Long categoryId;

  private Integer crossBorderFlag;

  private Integer isJit;

  private Integer isOwnImported;

  private Integer skuStatus;

  /**
   * SKU类型
   * @return
   */
  public String getSkuTypeStr() {
    String result = "";
    if (this.skuType != null) {
      // 1原材料2半成品3成品
      if (this.skuType.intValue() == 1) {
        result = "原材料";
      } else if (this.skuType.intValue() == 2) {
        result = "半成品";
      } else if (this.skuType.intValue() == 3) {
        result = "成品";
      }
    }
    return result;
  }

  public String getNameCn() {
    return nameCn;
  }

  public void setNameCn(String nameCn) {
    this.nameCn = nameCn;
  }

  public Integer getSkuType() {
    return skuType;
  }

  public void setSkuType(Integer skuType) {
    this.skuType = skuType;
  }



  public Integer getCrossBorderFlag() {
    return crossBorderFlag;
  }

  public void setCrossBorderFlag(Integer crossBorderFlag) {
    this.crossBorderFlag = crossBorderFlag;
  }

  public Integer getIsJit() {
    return isJit;
  }

  public void setIsJit(Integer isJit) {
    this.isJit = isJit;
  }

  public Long getCategoryId() {
    return categoryId;
  }

  public void setCategoryId(Long categoryId) {
    this.categoryId = categoryId;
  }

  public Integer getIsOwnImported() {
    return isOwnImported;
  }

  public void setIsOwnImported(Integer isOwnImported) {
    this.isOwnImported = isOwnImported;
  }

  public Integer getSkuStatus() {
    return skuStatus;
  }

  public void setSkuStatus(Integer skuStatus) {
    this.skuStatus = skuStatus;
  }

  public String getSkuCode() {
    return skuCode;
  }

  public void setSkuCode(String skuCode) {
    this.skuCode = skuCode;
  }
}
